/*
 * PointOfInterestEntity.java
 *
 * AUTO_COPY_RIGHT_SUB_TAG
 */

package com.rim.samples.device.unifiedsearchdemo;

import net.rim.device.api.ui.image.*;
import net.rim.device.api.unifiedsearch.*;
import net.rim.device.api.unifiedsearch.action.*;
import net.rim.device.api.unifiedsearch.entity.*;
import net.rim.device.api.unifiedsearch.searchables.*;

/**
 * Implementation of a point of interest searchable entity.  This basic
 * implementation does not provide any UI actions that might be associated
 * with this entity.
 */
public class PointOfInterestEntity implements SearchableEntity
{     
    private PointOfInterest _poi;    
    private PointOfInterestSearchable _searchable;    
    private SearchFieldCriteriaList _searchFieldCriteria;
    private Image _icon;   

    /**
     * Creates a new PointOfInterestEntity
     * 
     * @param poi A reference to the PointOfInterest this entity is associated with
     * @param searchable A reference to the PointOfInterestSearchable this entity is associated with
     * @throws NullPointerException if arguments are null
     */
    public PointOfInterestEntity(PointOfInterest poi, PointOfInterestSearchable searchable)
    {
        _poi = poi;
        _searchable = searchable;
        _searchFieldCriteria = new SearchFieldCriteriaList();

        // Get POI search fields
        SearchField[] fields = _searchable.defineSupportedSearchFields();

        for(int i = 0; i < fields.length; i++)
        {
            _searchFieldCriteria.addCriteria(new SearchFieldCriteria(fields[i], new String[]{_poi.getName()}));
        }
        _icon = searchable.getIcon();                    
    }

    public Object getData()
    {
        return _poi.getName();
    }

    public SearchFieldCriteriaList getSearchCriteria()
    {        
        return _searchFieldCriteria;
    }

    public Searchable getSearchable()
    {
        return _searchable;
    }
	
    public String getSummary()
    {
        // Return the summary that will be shown when this entity appears in search results                
        return _poi.getAddress();
    }

    public String getTitle()
    {
        // Return the title that will be shown when this entity appears in search results
        return _poi.getName();
    }

    public Image getIcon()
    {
        // Return the icon that will be shown when this entity appears in search results
        return _icon;
    }

    public long getTimeStamp()
    {
        return 0;
    }   

    public UiAction getUiActions(Object contextObject, UiAction[] uiActions)
    {
		//CODE FOR SEARCH RESULT ON CLICK ACTION GOES HERE
        return null;
    }   
}
